
#ifndef _C13_fi635_
#define _C13_fi635_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F542_2686(EIF_REFERENCE);
extern void EIF_Minit635(void);
extern EIF_INTEGER_32 F642_3164(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
